function I=pedersen_adapted(q,parameters)
%this function calculates the scattering from polydisperse spheres
%convoluted with a structure factor for fractal systems, as described by
%Teixeira, j.app.cryst. 1988, 21, 781
%the adaptation here is an adaptation to decouple the scattering signal
%from the polydisperse fractal structure from the polydisperse sphere
%structure. Teixeira indicates that for a polydisperse fractal situation, a
%const ant slope is added to the scattering signal. Effectively, then, this
%function considers a scattering system consisting of two separate
%components; a gel-like fractal component and polydisperse spheres.
%
%parameters:
%I0f: fractal background level
%D: slope of the fractal scattering (between 1 and 4)
%I0: scaling factor of the polydisperse system
%Rmu: mean and
%Rsigma: varianc of the schultz distributino
%bgnd: abackground level

%not monodisperse
parami=1;
I0f=parameters(parami);parami=parami+1;
D=parameters(parami);parami=parami+1;
I0=parameters(parami);parami=parami+1;
Rmu=parameters(parami);parami=parami+1;
Rsigma=parameters(parami);parami=parami+1;
bgnd=parameters(parami);
nsteps_PDint=800;
%PDint_cutoff=.99;
%PDint_start=.01;
RDint_start=0;
RDint_end=Rmu+40*abs(Rsigma);
Z=1./(Rsigma/Rmu)^2-1;
    DRD=(RDint_end-RDint_start)/nsteps_PDint;
    RDmid=0.5*DRD:DRD:RDint_end-0.5*DRD;    
    RDg=schultz(RDmid,Rmu,Z);
    %now everything is in place for the integration over R1.
Iint=zeros(size(q));
Vwsqrtot=0;
    for pdi=1:nsteps_PDint
            R=RDmid(pdi);
            V=2*pi*R^3;
            
            Fsph=sphereintensity_rayleigh(q.*R); %this function is not volume dependent, so we must remember to multiply with the volume
            Iint=Iint+V.^2.*abs(Fsph).^2.*RDg(pdi).*DRD;
            Vwsqrtot=Vwsqrtot+V.^2.*RDg(pdi).*DRD;

%        edi{pdi}=ed;
       
    end
    Iint=Iint./Vwsqrtot; %normalize so that F(0)=1 and multiply with the structure factor
            I=I0.*(Iint)+I0f.*q.^(-D)+bgnd;

% 
% function S=sfact(q,parameters)
% parami=1;
% rzero=parameters(parami);parami=parami+1;
% D=parameters(parami);parami=parami+1;
% eta=parameters(parami);%parami=parami+1;
% 
% S=D.*gamma(D-1)./(q.*rzero).^D.*1./(1+1./(q.^2.*eta.^2)).^((D-1)/2).*sin((D-1).*atan(q.*eta));
% 

%function I=PD_intensity(functionname,q,parameters,variance)

% funchandle=str2func(functionname);
% 
% Id=funchandle(q,parameters)

function Fsph=sphereintensity_rayleigh(qR)

%this is the intensity calcultion at q for a sphere with radius R.
%as given in the paper by J.S. Pedersen, 1997, (eqn. 55)

Fsph=(qR>=0.05).*3.*(sin(qR)-qR.*cos(qR))./qR.^3+(qR<0.05).*(1-0.1.*qR.^2);